This is unreleased documentation for the main (development) branch of crypto-glue.

ParseStream

Type Alias ParseStream 

pub type ParseStream<'a> = &'a ParseBuffer<'a>;
Input to a Syn parser function.

See the methods of this type under the documentation of ParseBuffer. For an overview of parsing in Syn, refer to the module documentation.